mod_switch.Rd
This simple module is used for demonstration purposes in documentation
switch_UI(id, name) switch_server(id, selected, switch_func) mod_switch(name, selected, module_id)
the shiny module id+
A title that will be shown inside the module
The name of the tab that we want to switch to
a function that when passed the name of a tab switches the focus to it
shiny module ID
switch_UI(): Module UI
switch_UI()
switch_server(): Module server
switch_server()